@@ -180,13 +180,13 @@ import pathlib
 from pprint import pformat
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-from ae.base import norm_line_sep, norm_name                                    # type: ignore
-from ae.core import DEBUG_LEVEL_VERBOSE                                         # type: ignore
-from ae.i18n import get_f_string                                                # type: ignore
-from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
+from ae.base import file_content, file_write, norm_line_sep, norm_name, os_platform         # type: ignore
+from ae.core import DEBUG_LEVEL_VERBOSE                                                     # type: ignore
+from ae.i18n import get_f_string                                                            # type: ignore
+from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action               # type: ignore
 
 
-__version__ = '0.1.36'
+__version__ = '0.1.37'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -532,14 +532,13 @@ class LiszDataMixin(ABC):
 
         return ""
 
-    def export_node(self, flow_path: List[str], file_path: str = ".", node: Optional[LiszNode] = None
-                    ) -> Optional[Exception]:
+    def export_node(self, flow_path: List[str], file_path: str = ".", node: Optional[LiszNode] = None) -> str:
         """ export node specified by the passed :paramref:`~export_node.flow_path` argument.
 
         :param flow_path:   flow path of the node to export.
         :param file_path:   folder to store the node data into (def=current working directory).
         :param node:        explicit/filtered node items (if not passed then all items will be exported).
-        :return:            `None` if node got exported without errors, else the raised exception.
+        :return:            empty string if node got exported without errors, else the error message/raised exception.
         """
         if not node:
             node = self.flow_path_node(flow_path)
@@ -550,11 +549,11 @@ class LiszDataMixin(ABC):
         try:
             # the alternative `os.makedirs(exist_ok=True)` has problems on POSIX with '..' in the path
             pathlib.Path(file_path).mkdir(parents=True, exist_ok=True)
-            with open(os.path.join(file_path, file_name), 'w') as file_handle:
-                file_handle.write(pformat(node))
+            err_msg = "" if file_write(pformat(node), os.path.join(file_path, file_name)) \
+                else f"export_node() error writing to file {os.path.join(file_path, file_name)}"
         except (FileExistsError, FileNotFoundError, OSError, ValueError) as ex:
-            return ex
-        return None
+            err_msg = str(ex)
+        return err_msg
 
     def find_item_index(self, item_id: str, searched_node: Optional[LiszNode] = None) -> int:
         """ determine list index of the passed item id in the searched node or in the current node.
@@ -729,6 +728,11 @@ class LiszDataMixin(ABC):
         :param folder_path: path to the folder where the node files are situated (def=current working directory).
         :return:            list of node file tuples of (node_name, node, file_path, error-message).
         """
+        if os_platform == 'android':                                                # pragma: no cover
+            # noinspection PyUnresolvedReferences
+            from android.permissions import request_permissions, Permission         # type: ignore
+            request_permissions([Permission.READ_EXTERNAL_STORAGE])
+
         node_file_info_tuples = list()
         for node_file in os.scandir(folder_path):
             file_name = node_file.name
@@ -750,18 +754,16 @@ class LiszDataMixin(ABC):
             if node_name.startswith(NODE_FILE_PREFIX):
                 node_name = node_name[len(NODE_FILE_PREFIX):]
 
-        try:
-            with open(file_path) as file_handle:
-                file_content = file_handle.read()
-        except (FileExistsError, FileNotFoundError, OSError) as ex:
-            return node_name, list(), file_path, f"file load error {ex}"
+        content = file_content(file_path, error_handling='strict')
+        if content is None:
+            return node_name, list(), file_path, "file load error"
 
-        file_len = len(file_content)
+        file_len = len(content)
         if file_len > IMPORT_NODE_MAX_FILE_LEN:
             return (node_name, list(), file_path,
                     f"import file is bigger than {IMPORT_NODE_MAX_FILE_LEN} bytes ({file_len})")
 
-        err_msg, _, node = flow_path_items_from_text(file_content)   # ignore optional flow path given in 1st line
+        err_msg, _, node = flow_path_items_from_text(content)       # ignore optional flow path given in 1st line
         if err_msg or not node:
             return node_name, list(), file_path, "invalid file content or empty file; ERR=" + err_msg
 
